clipt (|release|)
=================

clipt makes graphs using matplotlib from the command line

.. toctree::
   :maxdepth: 1

   clipt.plot
   cl_plot

.. include:: ../README.rst

.. toctree::
   :maxdepth: 3
   :hidden:

   history
   genindex
   search
   todo

